@@ -39,10 +39,8 @@ IP cores, etc. are handled close to the source code.
 * Handling of IP cores and simlib for your simulation project, with automatic re-compile when \
 necessary.
 * Python-based parallel Vivado build system.
-* Register code generation from TOML: VHDL package, HTML documentation, C header, C++ class.
-* VHDL AXI components that enable the register bus: AXI-to-AXI-Lite converter, \
-AXI-Lite interconnect, AXI-Lite mux (splitter), AXI-Lite clock domain crossing, AXI-Lite generic \
-register file.
+* Tightly integrated with `hdl_registers <https://hdl-registers.com>`__.
+  Register code generation will be performed before each simulation and each build.
 * Released under the very permissive BSD 3-Clause License.
 
 The maintainers place high focus on quality, with everything having good unit test coverage and a \
@@ -109,6 +107,8 @@ About tsfpga
         readme_rst = get_rst(include_link=True)
         if read_file(tsfpga.REPO_ROOT / "readme.rst") != readme_rst:
             file_path = create_file(tsfpga.TSFPGA_GENERATED / "sphinx" / "readme.rst", readme_rst)
-            assert False, f"readme.rst in repo root not correct. See file {file_path}"
+            assert (
+                False
+            ), f"readme.rst in repo root not correct. Compare to reference in python: {file_path}"
 
     return get_rst(include_link=include_website_link)
