@@ -6,13 +6,14 @@
 # https://gitlab.com/tsfpga/tsfpga
 # --------------------------------------------------------------------------------------------------
 
+from hdl_registers.parser import from_toml
+
 import tsfpga
 from tsfpga.constraint import Constraint
 from tsfpga.hdl_file import HdlFile
 from tsfpga.ip_core_file import IpCoreFile
 from tsfpga.module_list import ModuleList
 from tsfpga.system_utils import load_python_module
-from tsfpga.registers.parser import from_toml
 
 
 class BaseModule:
@@ -26,7 +27,7 @@ class BaseModule:
     def __init__(self, path, library_name, default_registers=None):
         """
         Arguments:
-            path (`pathlib.Path`): Path to the module folder.
+            path (pathlib.Path): Path to the module folder.
             library_name (str): VHDL library name.
             default_registers (list(Register)): Default registers.
         """
@@ -138,7 +139,7 @@ class BaseModule:
                 files are included.
 
         Return:
-            list(:class:`.HdlFile`): Files that should be included in a synthesis project.
+            list(HdlFile): Files that should be included in a synthesis project.
         """
         self.create_regs_vhdl_package()
 
@@ -169,7 +170,7 @@ class BaseModule:
                 files are included.
 
         Return:
-            list(:class:`.HdlFile`): Files that should be included in a simulation project.
+            list(HdlFile): Files that should be included in a simulation project.
         """
         test_folders = [
             self.path / "sim",
@@ -204,7 +205,7 @@ class BaseModule:
                 files are included.
 
         Return:
-            list(:class:`.HdlFile`): Files that should be included in a formal verification project.
+            list(HdlFile): Files that should be included in a formal verification project.
         """
         return self.get_simulation_files(
             include_tests=False, files_include=files_include, files_avoid=files_avoid, **kwargs
@@ -227,7 +228,7 @@ class BaseModule:
                 IP cores are included and what their variables are.
 
         Return:
-            list(:class:`.IpCoreFile`): The IP cores for this module.
+            list(IpCoreFile): The IP cores for this module.
         """
         folders = [
             self.path / "ip_cores",
@@ -255,7 +256,7 @@ class BaseModule:
                 constraints are included.
 
         Return:
-            list(:class:`.Constraint`): The constraints.
+            list(Constraint): The constraints.
         """
         folders = [
             self.path / "scoped_constraints",
@@ -346,7 +347,7 @@ class BaseModule:
             build projects.
 
         Return:
-            list(:class:`.VivadoProject`): FPGA build projects.
+            list(VivadoProject): FPGA build projects.
         """
         return []
 
@@ -382,22 +383,6 @@ class BaseModule:
         return f"{self.name}:{self.path}"
 
 
-def iterate_module_folders(modules_folders):
-    for modules_folder in modules_folders:
-        for module_folder in modules_folder.glob("*"):
-            if module_folder.is_dir():
-                yield module_folder
-
-
-def get_module_object(path, name, library_name_has_lib_suffix, default_registers):
-    module_file = path / f"module_{name}.py"
-    library_name = f"{name}_lib" if library_name_has_lib_suffix else name
-
-    if module_file.exists():
-        return load_python_module(module_file).Module(path, library_name, default_registers)
-    return BaseModule(path, library_name, default_registers)
-
-
 def get_modules(
     modules_folders,
     names_include=None,
@@ -409,7 +394,7 @@ def get_modules(
     Get a list of Module objects based on the source code folders.
 
     Arguments:
-        modules_folders (list(`pathlib.Path`)): A list of paths where your modules are located.
+        modules_folders (list(pathlib.Path)): A list of paths where your modules are located.
         names_include (list(str)): If specified, only modules with these names will be included.
         names_avoid (list(str)): If specified, modules with these names will be discarded.
         library_name_has_lib_suffix (bool): If set, the library name will be
@@ -422,7 +407,7 @@ def get_modules(
     """
     modules = ModuleList()
 
-    for module_folder in iterate_module_folders(modules_folders):
+    for module_folder in _iterate_module_folders(modules_folders):
         module_name = module_folder.name
 
         if names_include is not None and module_name not in names_include:
@@ -432,7 +417,7 @@ def get_modules(
             continue
 
         modules.append(
-            get_module_object(
+            _get_module_object(
                 module_folder, module_name, library_name_has_lib_suffix, default_registers
             )
         )
@@ -440,16 +425,60 @@ def get_modules(
     return modules
 
 
-def get_tsfpga_modules(names_include=None, names_avoid=None):
+def _iterate_module_folders(modules_folders):
+    for modules_folder in modules_folders:
+        for module_folder in modules_folder.glob("*"):
+            if module_folder.is_dir():
+                yield module_folder
+
+
+def _get_module_object(path, name, library_name_has_lib_suffix, default_registers):
+    module_file = path / f"module_{name}.py"
+    library_name = f"{name}_lib" if library_name_has_lib_suffix else name
+
+    if module_file.exists():
+        return load_python_module(module_file).Module(path, library_name, default_registers)
+    return BaseModule(path, library_name, default_registers)
+
+
+def get_hdl_modules(names_include=None, names_avoid=None):
     """
-    Wrapper of the regular :func:`.get_modules`. call with correct settings for tsfpga modules.
-    This will include the "real" tsfpga modules, but not the example modules.
+    Wrapper of :func:`.get_modules` which returns the ``hdl_modules`` module objects.
+    If this is a PyPI release of tsfpga, a release of ``hdl_modules`` will be bundled and modules
+    from there will be returned.
+
+    If this is a repo checkout of tsfpga, the function will try to find the ``hdl_modules`` repo
+    if it is next to the tsfpga repo.
+
+    If neither of those alternatives work, the function will assert False.
 
     Arguments will be passed on to :func:`.get_modules`.
+
+    Return:
+        :class:`.ModuleList`: The module objects.
     """
-    return get_modules(
-        modules_folders=[tsfpga.TSFPGA_MODULES],
-        names_include=names_include,
-        names_avoid=names_avoid,
-        library_name_has_lib_suffix=False,
+    if tsfpga.HDL_MODULES_LOCATION is not None:
+        if not tsfpga.HDL_MODULES_LOCATION.exists():
+            raise FileNotFoundError(
+                f"The marked location {tsfpga.HDL_MODULES_LOCATION} does not exist. "
+                "There is something wrong with the release script."
+            )
+
+        return get_modules(
+            modules_folders=[tsfpga.HDL_MODULES_LOCATION],
+            names_include=names_include,
+            names_avoid=names_avoid,
+        )
+
+    # Presumed location of the hdl_modules repo
+    hdl_modules_repo_root = (tsfpga.REPO_ROOT.parent / "hdl_modules").resolve()
+    if (hdl_modules_repo_root / "modules").exists():
+        return get_modules(
+            modules_folders=[hdl_modules_repo_root / "modules"],
+            names_include=names_include,
+            names_avoid=names_avoid,
+        )
+
+    raise FileNotFoundError(
+        f"The hdl_modules modules could not be found. Searched in {hdl_modules_repo_root}"
     )
