@@ -12,8 +12,10 @@ import pytest
 import tsfpga
 
 # Do PYTHONPATH insert() instead of append() to prefer any local repo checkout over any pip install
-PATH_TO_VUNIT = tsfpga.REPO_ROOT.parent.parent / "vunit" / "vunit"
-sys.path.insert(0, str(PATH_TO_VUNIT.resolve()))
+PATH_TO_HDL_REGISTERS = tsfpga.REPO_ROOT.parent.resolve() / "hdl_registers"
+sys.path.insert(0, str(PATH_TO_HDL_REGISTERS))
+PATH_TO_VUNIT = tsfpga.REPO_ROOT.parent.parent.resolve() / "vunit" / "vunit"
+sys.path.insert(0, str(PATH_TO_VUNIT))
 
 
 @pytest.fixture
