@@ -23,9 +23,9 @@ class VivadoSimlib:
         for detecting the simulator currently in use.
 
         Arguments:
-            output_path (`pathlib.Path`): The compiled simlib will be placed here.
+            output_path (pathlib.Path): The compiled simlib will be placed here.
             vunit_proj: The VUnit project that is used to run simulation.
-            vivado_path (`pathlib.Path`): Path to Vivado executable. If left out, the default
+            vivado_path (pathlib.Path): Path to Vivado executable. If left out, the default
                 from PATH will be used.
         Return:
             A :class:`.VivadoSimlibCommon` child object.
